@@ -80,7 +80,7 @@ static void sensor_config_dialog_response(GtkDialog *dialog,
         case GTK_RESPONSE_HELP:
                 g_debug("loading help in config dialog");
                 gtk_show_uri(NULL,
-			     "http://wiki.mate-desktop.org/docs:mate-sensors-applet",
+			     "help:mate-sensors-applet/sensors-applet-sensors#sensors-applet-sensor-config-dialog",
 			     gtk_get_current_event_time(),
 			     &error);
                 
@@ -323,6 +323,7 @@ static void sensor_config_dialog_graph_color_set(GtkColorButton *color_button,
 	GtkTreeModel *model;
 	GtkTreePath *path;
 	GtkTreeIter iter;
+        GtkWidget *content_area;
 	GdkColor color;
         gchar *color_string;
 
@@ -352,6 +353,7 @@ static void sensor_config_dialog_graph_color_set(GtkColorButton *color_button,
 void sensor_config_dialog_create(SensorsApplet *sensors_applet) {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
+        GtkWidget *content_area;
 
         SensorConfigDialog *config_dialog;
 
@@ -395,13 +397,15 @@ void sensor_config_dialog_create(SensorsApplet *sensors_applet) {
 
 	config_dialog->dialog = gtk_dialog_new_with_buttons(header_text,
                                                             GTK_WINDOW(sensors_applet->prefs_dialog->dialog),
-                                                            GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR,
+                                                            GTK_DIALOG_DESTROY_WITH_PARENT,
                                                             GTK_STOCK_HELP,
                                                             GTK_RESPONSE_HELP,
                                                             GTK_STOCK_CLOSE,
                                                             GTK_RESPONSE_CLOSE,
                                                             NULL);
-        
+        gtk_window_set_icon_name(GTK_WINDOW(config_dialog->dialog),
+                                 "sensors-applet");
+
         g_free(header_text);
         g_free(sensor_label);
 
@@ -912,7 +916,8 @@ void sensor_config_dialog_create(SensorsApplet *sensors_applet) {
 				  2, 3,
 				  14, 15);
 
-	gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(config_dialog->dialog)->vbox), GTK_WIDGET(config_dialog->table));
+        content_area = gtk_dialog_get_content_area (GTK_DIALOG(config_dialog->dialog));
+	gtk_box_pack_start(GTK_BOX(content_area), GTK_WIDGET(config_dialog->table), FALSE, FALSE, 0);
 	gtk_widget_show_all(config_dialog->dialog);
 
 }		
