@@ -78,7 +78,7 @@ static void help_cb(GtkAction *action,
 
         GError *error = NULL;
         
-        gtk_show_uri(NULL, "http://wiki.mate-desktop.org/docs:mate-sensors-applet",
+        gtk_show_uri(NULL, "help:mate-sensors-applet",
 		     gtk_get_current_event_time(),
 		     &error);
         
@@ -123,45 +123,6 @@ static void destroy_cb(GtkWidget *widget, gpointer data) {
 	return;
 }
 
-static void change_background_cb(MatePanelApplet *applet, 
-				 MatePanelAppletBackgroundType type,
-				 GdkColor *color, 
-				 GdkPixmap *pixmap, 
-				 gpointer *data) {
-	GtkRcStyle *rc_style;
-	GtkStyle *style;
-
-        g_debug("change-background occurred");
-
-	/* reset style */
-	gtk_widget_set_style(GTK_WIDGET(applet), NULL);
-	rc_style = gtk_rc_style_new();
-	gtk_widget_modify_style(GTK_WIDGET(applet), rc_style);
-	gtk_rc_style_unref(rc_style);
-
-	switch(type) {
-	case PANEL_COLOR_BACKGROUND:
-		gtk_widget_modify_bg(GTK_WIDGET(applet),
-				     GTK_STATE_NORMAL, color);
-		break;
-
-	case PANEL_PIXMAP_BACKGROUND:
-		style = gtk_style_copy(GTK_WIDGET(applet)->style);
-		if (style->bg_pixmap[GTK_STATE_NORMAL]) {
-			g_object_unref(style->bg_pixmap[GTK_STATE_NORMAL]);
-		}
-		style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref(pixmap);
-		gtk_widget_set_style(GTK_WIDGET(applet), style);
-		g_object_unref(style);
-		break;
-
-	case PANEL_NO_BACKGROUND:
-		/* fall through */
-	default:
-		break;
-	}
-}
-
 static void change_orient_cb (MatePanelApplet *applet, 
                               MatePanelAppletOrient orient, 
                               gpointer data) {
@@ -547,8 +508,14 @@ static void sensors_applet_pack_display(SensorsApplet *sensors_applet) {
         case DISPLAY_VALUE:
                 gtk_widget_size_request(GTK_WIDGET(first_sensor->value),
                                         &req);
+/* FIXME, this can be done better somewhere for cairo */
+#if GTK_CHECK_VERSION (3, 0, 0)
+                value_width = req.width + COLUMN_SPACING + 10;
+                value_height = req.height + ROW_SPACING + 10;
+#else
                 value_width = req.width + COLUMN_SPACING;
                 value_height = req.height + ROW_SPACING;
+#endif
 
                 /* make sure all widths and heights are non zero,
                  * otherwise will get a divide by zero exception below
@@ -570,6 +537,16 @@ static void sensors_applet_pack_display(SensorsApplet *sensors_applet) {
                  * widgets directly */
                 gtk_widget_size_request(GTK_WIDGET(first_sensor->value),
                                         &req);
+/* FIXME, this can be done better somewhere for cairo */
+#if GTK_CHECK_VERSION (3, 0, 0)
+                value_width = req.width + COLUMN_SPACING + 10;
+                value_height = req.height + ROW_SPACING + 10;
+
+                gtk_widget_size_request(GTK_WIDGET(first_sensor->label),
+                                        &req);
+                label_width = req.width + COLUMN_SPACING + 10;
+                label_height = req.height + ROW_SPACING + 10;
+#else
                 value_width = req.width + COLUMN_SPACING;
                 value_height = req.height + ROW_SPACING;
 
@@ -577,6 +554,7 @@ static void sensors_applet_pack_display(SensorsApplet *sensors_applet) {
                                         &req);
                 label_width = req.width + COLUMN_SPACING;
                 label_height = req.height + ROW_SPACING;
+#endif
         
                 /* make sure all widths and heights are non zero, otherwise
                  * will get a divide by zero exception below 
@@ -607,6 +585,16 @@ static void sensors_applet_pack_display(SensorsApplet *sensors_applet) {
         case DISPLAY_ICON_WITH_VALUE:
                 gtk_widget_size_request(GTK_WIDGET(first_sensor->value),
                                         &req);
+/* FIXME, this can be done better somewhere for cairo */
+#if GTK_CHECK_VERSION (3, 0, 0)
+                value_width = req.width + COLUMN_SPACING +10;
+                value_height = req.height + ROW_SPACING + 10;
+
+                gtk_widget_size_request(GTK_WIDGET(first_sensor->icon),
+                                        &req);
+                icon_width = req.width + COLUMN_SPACING + 10;
+                icon_height = req.height + ROW_SPACING + 10;
+#else
                 value_width = req.width + COLUMN_SPACING;
                 value_height = req.height + ROW_SPACING;
 
@@ -614,6 +602,7 @@ static void sensors_applet_pack_display(SensorsApplet *sensors_applet) {
                                         &req);
                 icon_width = req.width + COLUMN_SPACING;
                 icon_height = req.height + ROW_SPACING;
+#endif
                 
                 if (!(icon_width && icon_height &&
                       value_width && value_height)) {
@@ -639,8 +628,14 @@ static void sensors_applet_pack_display(SensorsApplet *sensors_applet) {
         case DISPLAY_ICON:
                 gtk_widget_size_request(GTK_WIDGET(first_sensor->icon),
                                         &req);
+/* FIXME, this can be done better somewhere for cairo */
+#if GTK_CHECK_VERSION (3, 0, 0)
+                icon_width = req.width + COLUMN_SPACING + 10;
+                icon_height = req.height + ROW_SPACING + 10;
+#else
                 icon_width = req.width + COLUMN_SPACING;
                 icon_height = req.height + ROW_SPACING;
+#endif
                 if (!(icon_width && icon_height)) {
                         return;
                 }
@@ -1344,6 +1339,10 @@ void sensors_applet_init(SensorsApplet *sensors_applet) {
 	GtkActionGroup *action_group;
 	gchar *ui_path;
 
+	/* Have our background automatically painted. */
+	mate_panel_applet_set_background_widget(MATE_PANEL_APPLET(sensors_applet->applet),
+		GTK_WIDGET(sensors_applet->applet));
+
         /* plugin functions are stored as name -> get_value_function pairs so
          * use standard string functions on hash table */
         sensors_applet->plugins = g_hash_table_new(g_str_hash,
@@ -1397,10 +1396,6 @@ void sensors_applet_init(SensorsApplet *sensors_applet) {
 			 G_CALLBACK(style_set_cb),
 			 sensors_applet);
 
-	g_signal_connect(sensors_applet->applet, "change_background",
-			 G_CALLBACK(change_background_cb), 
-			 sensors_applet);
-
         g_signal_connect(G_OBJECT(sensors_applet->applet), "change_orient",
                           G_CALLBACK(change_orient_cb), 
                           sensors_applet);
